@@ -108,11 +108,11 @@ func (e *AgeEncryption) builtinDecrypt(ciphertext []byte) ([]byte, error) {
 	if err != nil {
 		return nil, err
 	}
-	w := &bytes.Buffer{}
-	if _, err = io.Copy(w, r); err != nil {
+	buffer := &bytes.Buffer{}
+	if _, err = io.Copy(buffer, r); err != nil {
 		return nil, err
 	}
-	return w.Bytes(), err
+	return buffer.Bytes(), err
 }
 
 // builtinEncrypt encrypts ciphertext using the builtin age.
@@ -178,6 +178,13 @@ func (e *AgeEncryption) builtinRecipients() ([]age.Recipient, error) {
 		}
 		recipients = append(recipients, parsedRecipient)
 	}
+	if !e.RecipientsFile.Empty() {
+		parsedRecipients, err := parseRecipientsFile(e.RecipientsFile)
+		if err != nil {
+			return nil, err
+		}
+		recipients = append(recipients, parsedRecipients...)
+	}
 	for _, recipientsFile := range e.RecipientsFiles {
 		parsedRecipients, err := parseRecipientsFile(recipientsFile)
 		if err != nil {
