@@ -17,6 +17,7 @@ import (
 	"net/url"
 	"os"
 	"os/exec"
+	"path"
 	"runtime"
 	"sort"
 	"strings"
@@ -641,9 +642,9 @@ func (s *SourceState) ExecuteTemplateData(name string, data []byte) ([]byte, err
 	return []byte(builder.String()), nil
 }
 
-// Ignored returns if targetRelPath is ignored.
-func (s *SourceState) Ignored(targetRelPath RelPath) bool {
-	return s.ignore.match(string(targetRelPath))
+// Ignore returns if targetRelPath should be ignored.
+func (s *SourceState) Ignore(targetRelPath RelPath) bool {
+	return s.ignore.match(targetRelPath.String())
 }
 
 // MinVersion returns the minimum version for which s is valid.
@@ -735,7 +736,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			}
 			n := 0
 			for _, match := range matches {
-				if !s.Ignored(RelPath(match)) {
+				if !s.Ignore(RelPath(match)) {
 					matches[n] = match
 					n++
 				}
@@ -743,7 +744,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			targetParentRelPath := parentSourceRelPath.TargetRelPath(s.encryption.EncryptedSuffix())
 			matches = matches[:n]
 			for _, match := range matches {
-				targetRelPath := targetParentRelPath.Join(RelPath(match))
+				targetRelPath := targetParentRelPath.JoinStr(match)
 				sourceStateEntry := &SourceStateRemove{
 					targetRelPath: targetRelPath,
 				}
@@ -767,7 +768,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 		case info.IsDir():
 			da := parseDirAttr(sourceName.String())
 			targetRelPath := parentSourceRelPath.Dir().TargetRelPath(s.encryption.EncryptedSuffix()).Join(RelPath(da.TargetName))
-			if s.Ignored(targetRelPath) {
+			if s.Ignore(targetRelPath) {
 				return vfs.SkipDir
 			}
 			sourceStateEntry := s.newSourceStateDir(sourceRelPath, da)
@@ -776,7 +777,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 		case info.Mode().IsRegular():
 			fa := parseFileAttr(sourceName.String(), s.encryption.EncryptedSuffix())
 			targetRelPath := parentSourceRelPath.Dir().TargetRelPath(s.encryption.EncryptedSuffix()).Join(RelPath(fa.TargetName))
-			if s.Ignored(targetRelPath) {
+			if s.Ignore(targetRelPath) {
 				return nil
 			}
 			var sourceStateEntry SourceStateEntry
@@ -802,7 +803,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 		return externalRelPaths[i] < externalRelPaths[j]
 	})
 	for _, externalRelPath := range externalRelPaths {
-		if s.Ignored(externalRelPath) {
+		if s.Ignore(externalRelPath) {
 			continue
 		}
 		externalSourceStateEntries, err := s.readExternal(ctx, externalRelPath, s.externals[externalRelPath], options)
@@ -810,7 +811,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			return err
 		}
 		for targetRelPath, sourceStateEntries := range externalSourceStateEntries {
-			if s.Ignored(targetRelPath) {
+			if s.Ignore(targetRelPath) {
 				continue
 			}
 			allSourceStateEntries[targetRelPath] = append(allSourceStateEntries[targetRelPath], sourceStateEntries...)
@@ -819,7 +820,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 
 	// Remove all ignored targets.
 	for targetRelPath := range allSourceStateEntries {
-		if s.Ignored(targetRelPath) {
+		if s.Ignore(targetRelPath) {
 			delete(allSourceStateEntries, targetRelPath)
 		}
 	}
@@ -844,11 +845,11 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				if name == "." || name == ".." {
 					continue
 				}
-				destEntryRelPath := targetRelPath.Join(RelPath(name))
+				destEntryRelPath := targetRelPath.JoinStr(name)
 				if _, ok := allSourceStateEntries[destEntryRelPath]; ok {
 					continue
 				}
-				if s.Ignored(destEntryRelPath) {
+				if s.Ignore(destEntryRelPath) {
 					continue
 				}
 				allSourceStateEntries[destEntryRelPath] = append(allSourceStateEntries[destEntryRelPath], &SourceStateRemove{
@@ -994,7 +995,7 @@ func (s *SourceState) addPatterns(patternSet *patternSet, sourceAbsPath AbsPath,
 			include = false
 			text = mustTrimPrefix(text, "!")
 		}
-		pattern := string(dir.Join(RelPath(text)))
+		pattern := string(dir.JoinStr(text))
 		if err := patternSet.add(pattern, include); err != nil {
 			return fmt.Errorf("%s:%d: %w", sourceAbsPath, lineNumber, err)
 		}
@@ -1098,7 +1099,7 @@ func (s *SourceState) getExternalDataRaw(ctx context.Context, externalRelPath Re
 	now = now.UTC()
 
 	cacheKey := hex.EncodeToString(SHA256Sum([]byte(external.URL)))
-	cachedDataAbsPath := s.cacheDirAbsPath.Join("external", RelPath(cacheKey+"."+externalCacheFormat.Name()))
+	cachedDataAbsPath := s.cacheDirAbsPath.JoinStr("external", cacheKey+"."+externalCacheFormat.Name())
 	if options == nil || !options.RefreshExternals {
 		if data, err := s.system.ReadFile(cachedDataAbsPath); err == nil {
 			var externalCacheEntry externalCacheEntry
@@ -1590,9 +1591,9 @@ func (s *SourceState) readExternalArchive(ctx context.Context, externalRelPath R
 	if err != nil {
 		return nil, fmt.Errorf("%s: %s: %w", externalRelPath, external.URL, err)
 	}
-	path := url.Path
+	urlPath := url.Path
 	if external.Encrypted {
-		path = strings.TrimSuffix(path, s.encryption.EncryptedSuffix())
+		urlPath = strings.TrimSuffix(urlPath, s.encryption.EncryptedSuffix())
 	}
 	sourceRelPath := NewSourceRelPath(RelPath(external.URL))
 	sourceStateEntries := map[RelPath][]SourceStateEntry{
@@ -1612,7 +1613,7 @@ func (s *SourceState) readExternalArchive(ctx context.Context, externalRelPath R
 
 	format := external.Format
 	if format == ArchiveFormatUnknown {
-		format = GuessArchiveFormat(path, data)
+		format = GuessArchiveFormat(urlPath, data)
 	}
 
 	if err := walkArchive(data, format, func(name string, info fs.FileInfo, r io.Reader, linkname string) error {
@@ -1621,14 +1622,14 @@ func (s *SourceState) readExternalArchive(ctx context.Context, externalRelPath R
 			if len(components) <= external.StripComponents {
 				return nil
 			}
-			name = strings.Join(components[external.StripComponents:], "/")
+			name = path.Join(components[external.StripComponents:]...)
 		}
 		if name == "" {
 			return nil
 		}
-		targetRelPath := externalRelPath.Join(RelPath(name))
+		targetRelPath := externalRelPath.JoinStr(name)
 
-		if s.Ignored(targetRelPath) {
+		if s.Ignore(targetRelPath) {
 			return nil
 		}
 
